@@ -223,14 +223,14 @@ class RpcExchangerClient:
             log.debug(f"{raw_message['data']=} {raw_message['channel']=}")
             try:
                 json_content_untyped: Any = json.loads(raw_message["data"].decode())
-                if raw_message["channel"].startswith("messages"):
+                if raw_message["channel"].startswith(b"messages"):
                     json_message: RedisMessage = json_content_untyped
                     username = json_message["username"]
                     msg = json_message["msg"]
                     chat = int(raw_message["channel"][9:])
                     log.debug(f"{username=} {msg=} {chat=}")
                     return "message", username, msg, chat
-                elif raw_message["channel"].startswith("events"):
+                elif raw_message["channel"].startswith(b"events"):
                     json_content: RedisEvent = json_content_untyped
                     type = json_content["type"]
                     data = json_content["data"]
